summaryrefslogtreecommitdiffstats
path: root/util
diff options
context:
space:
mode:
authorZheng Bao <fishbaozi@gmail.com>2020-10-06 12:03:11 +0800
committerPatrick Georgi <pgeorgi@google.com>2020-11-04 09:42:18 +0000
commit3384e4a709b97071a67b724bc9f4a4208f0f5fe8 (patch)
treed4ddab0e65f77385d320c50441ee5605d72111ce /util
parent77a2c67dfe94e1dac09c5878d9963d30fae2a90f (diff)
downloadcoreboot-3384e4a709b97071a67b724bc9f4a4208f0f5fe8.tar.gz
coreboot-3384e4a709b97071a67b724bc9f4a4208f0f5fe8.tar.bz2
coreboot-3384e4a709b97071a67b724bc9f4a4208f0f5fe8.zip
soc/amd: Change FIRMWARE_LOCATE to FIRMWARE_LOCATION
Change-Id: I3a3d187fc24ab752dfe61893c15561a92d009fe2 Signed-off-by: Zheng Bao <fishbaozi@gmail.com> Reviewed-on: https://review.coreboot.org/c/coreboot/+/46062 Reviewed-by: Felix Held <felix-coreboot@felixheld.de> Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
Diffstat (limited to 'util')
-rw-r--r--util/amdfwtool/data_parse.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/util/amdfwtool/data_parse.c b/util/amdfwtool/data_parse.c
index 2af6c3199160..b3470d54ccd7 100644
--- a/util/amdfwtool/data_parse.c
+++ b/util/amdfwtool/data_parse.c
@@ -359,13 +359,13 @@ uint8_t process_config(FILE *config, amd_cb_config *cb_config, uint8_t print_dep
entries_line_regex, &entries_line_expr);
/* Get a line */
/* Get FIRMWARE_LOCATE in the first loop */
while (get_input_file_line(config, oneline, MAX_LINE_SIZE) == OK) {
/* get a line */
if (skip_comment_blank_line(oneline))
continue;
if (is_valid_entry(oneline, match)) {
- if (strcmp(&(oneline[match[1].rm_so]), "FIRMWARE_LOCATE") == 0) {
+ if (strcmp(&(oneline[match[1].rm_so]), "FIRMWARE_LOCATION") == 0) {
strcpy(dir, &(oneline[match[2].rm_so]));
break;
}
@@ -384,7 +384,7 @@ uint8_t process_config(FILE *config, amd_cb_config *cb_config, uint8_t print_dep
if (skip_comment_blank_line(oneline))
continue;
if (is_valid_entry(oneline, match)) {
- if (strcmp(&(oneline[match[1].rm_so]), "FIRMWARE_LOCATE") == 0) {
+ if (strcmp(&(oneline[match[1].rm_so]), "FIRMWARE_LOCATION") == 0) {
continue;
} else {
path_filename = malloc(MAX_LINE_SIZE);
@@ -359,13 +359,13 @@ uint8_t process_config(FILE *config, amd_cb_config *cb_config, uint8_t print_dep
entries_line_regex, &entries_line_expr);
/* Get a line */
- /* Get FIRMWARE_LOCATE in the first loop */
+ /* Get FIRMWARE_LOCATION in the first loop */
while (get_input_file_line(config, oneline, MAX_LINE_SIZE) == OK) {
/* get a line */